@@ -1,30 +1,33 @@
 /***************************************************************************
-                          plugin_katesymbolviewer.cpp  -  description
-                             -------------------
-    begin                : Apr 2 2003
-    author               : 2003 Massimo Callegari
-    email                : massimocallegari@yahoo.it
-
-    Changes:
-    Apr 07 2003 v 0.1 - First version.
-    Apr 19 2003 v 0.2 - Added to CVS. Extract functions and structures
-    Apr 22 2003 v 0.3 - Added macro extraction + several bugfixing
-    Apr 23 2003 v 0.4 - "View Symbol" moved in Settings menu. "Refresh List" is no
-                        longer in Kate menu. Moved into a popup menu activated by a
-                        mouse right button click. + Bugfixing.
-    Apr 24 2003 v 0.5 - Added three check buttons in popup menu to show/hide symbols
-    May 04 2003 v 0.6 - Symbol List becomes a KListView object. Removed Tooltip class.
-                        Added a QTimer that every 200ms checks:
-                        * if the list width has changed
-                        * if the document has changed
-                        Added an entry in the popup menu to switch between List and Tree mode
-                        Various bugfixing.
-    Jun 19 2003 v.1.0 - Removed QTimer (polling is Evil(tm)... )
-                        - Captured documentChanged() event to refresh symbol list
-                        - Tooltips vanished into nowhere...sigh :(
-    Nov 28 2003 v.1.1 - Structured for multilanguage support
-                        Added preliminary Tcl/Tk parser (thanks Rohit). To be improved.
-                        Various bugfixing.
+ *                        plugin_katesymbolviewer.cpp  -  description
+ *                           -------------------
+ *  begin                : Apr 2 2003
+ *  author               : 2003 Massimo Callegari
+ *  email                : massimocallegari@yahoo.it
+ *
+ *  Changes:
+ *  Nov 09 2004 v.1.3 - For changelog please refer to KDE CVS
+ *  Nov 05 2004 v.1.2 - Choose parser from the current highlight. Minor i18n changes.
+ *  Nov 28 2003 v.1.1 - Structured for multilanguage support
+ *                      Added preliminary Tcl/Tk parser (thanks Rohit). To be improved.
+ *                      Various bugfixing.
+ *  Jun 19 2003 v.1.0 - Removed QTimer (polling is Evil(tm)... )
+ *                      - Captured documentChanged() event to refresh symbol list
+ *                      - Tooltips vanished into nowhere...sigh :(
+ *  May 04 2003 v 0.6 - Symbol List becomes a KListView object. Removed Tooltip class.
+ *                      Added a QTimer that every 200ms checks:
+ *                      * if the list width has changed
+ *                      * if the document has changed
+ *                      Added an entry in the popup menu to switch between List and Tree mode
+ *                      Various bugfixing.
+ *  Apr 24 2003 v 0.5 - Added three check buttons in popup menu to show/hide symbols
+ *  Apr 23 2003 v 0.4 - "View Symbol" moved in Settings menu. "Refresh List" is no
+ *                      longer in Kate menu. Moved into a popup menu activated by a
+ *                      mouse right button click. + Bugfixing.
+ *  Apr 22 2003 v 0.3 - Added macro extraction + several bugfixing
+ *  Apr 19 2003 v 0.2 - Added to CVS. Extract functions and structures
+ *  Apr 07 2003 v 0.1 - First version.
+ *
  ***************************************************************************/
 /***************************************************************************
  *                                                                         *
@@ -42,16 +45,18 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kgenericfactory.h>
+#include <kfiledialog.h>
+
+#include <qlayout.h>
+#include <qgroupbox.h>
 
 K_EXPORT_COMPONENT_FACTORY( katecppsymbolviewerplugin, KGenericFactory<KatePluginSymbolViewer>( "katesymbolviewer" ) )
 
 KatePluginSymbolViewerView::KatePluginSymbolViewerView(Kate::MainWindow *w)
 {
     KGlobal::locale()->insertCatalogue("katecppsymbolviewer");
-    KToggleAction* act = new KToggleAction ( i18n("Show Symbols"), 0, this,
-                      SLOT( slotInsertSymbol() ), actionCollection(),
-                      "view_insert_symbolviewer" );
-    act->setCheckedState(i18n("Hide Symbols"));
+    KToggleAction* act = new KToggleAction ( i18n("Hide Symbols"), 0, this, SLOT( slotInsertSymbol() ), actionCollection(),      "view_insert_symbolviewer" );
+    act->setCheckedState(i18n("Show Symbols"));
 
     setInstance (new KInstance("kate"));
     setXMLFile("plugins/katecppsymbolviewer/ui.rc");
@@ -75,6 +80,7 @@ KatePluginSymbolViewerView::KatePluginSymbolViewerView(Kate::MainWindow *w)
  macro_on = true;
  struct_on = true;
  func_on = true;
+ slotInsertSymbol();
 }
 
 KatePluginSymbolViewerView::~KatePluginSymbolViewerView()
@@ -82,6 +88,7 @@ KatePluginSymbolViewerView::~KatePluginSymbolViewerView()
   win->guiFactory()->removeClient (this);
   if (symbols)
     win->toolViewManager()->removeToolView(symbols);
+  delete popup;
 }
 
 void KatePluginSymbolViewerView::toggleShowMacros(void)
@@ -121,13 +128,16 @@ void KatePluginSymbolViewerView::slotInsertSymbol()
       connect(symbols, SIGNAL(rightButtonClicked(QListViewItem *, const QPoint&, int)),
                SLOT(slotShowContextMenu(QListViewItem *, const QPoint&, int)));
       connect(win->viewManager(), SIGNAL(viewChanged()), this, SLOT(slotDocChanged()));
-      connect(symbols, SIGNAL(resizeEvent(QResizeEvent * e)), this, SLOT(slotViewChanged(QResizeEvent * e)));
+      //connect(symbols, SIGNAL(resizeEvent(QResizeEvent *)), this, SLOT(slotViewChanged(QResizeEvent *)));
 
       win->toolViewManager()->addToolView(KDockWidget::DockLeft, symbols, cls, i18n("Symbol List"));
 
       m_Active = true;
       //symbols->addColumn(i18n("Symbols"), symbols->parentWidget()->width());
       symbols->addColumn(i18n("Symbols"));
+      symbols->addColumn(i18n("Position"));
+      symbols->setColumnWidthMode(1, QListView::Manual);
+      symbols->setColumnWidth ( 1, 0 );
       symbols->setSorting(-1, FALSE);
       symbols->setRootIsDecorated(0);
       symbols->setTreeStepSize(10);
@@ -178,6 +188,8 @@ void KatePluginSymbolViewerView::slotShowContextMenu(QListViewItem *, const QPoi
 
 void KatePluginSymbolViewerView::parseSymbols(void)
 {
+  unsigned int hlMode = 0;
+ 
   if (!win->viewManager()->activeView())
     return;
 
@@ -187,11 +199,16 @@ void KatePluginSymbolViewerView::parseSymbols(void)
   if (!kv)
     return;
 
-  QString docName = kv->docName();
-  if(docName.endsWith(".cpp") || docName.endsWith(".c") || docName.endsWith(".h"))
-      parseCppSymbols();
-  else if(docName.endsWith(".tcl") || docName.endsWith(".tk"))
-      parseTclSymbols();
+  /** Get the current highlighting mode */
+  hlMode = kv->hlMode();
+  QString hlModeName = kv->hlModeName(hlMode);
+  
+  //QListViewItem mcrNode = new QListViewItem(symbols, symbols->lastItem(), hlModeName);
+  
+  if (hlModeName == "C++" || hlModeName == "C")
+     parseCppSymbols();
+  else if (hlModeName == "Tcl/Tk")
+     parseTclSymbols();
 }
 
 void KatePluginSymbolViewerView::goToSymbol(QListViewItem *it)
@@ -203,24 +220,32 @@ void KatePluginSymbolViewerView::goToSymbol(QListViewItem *it)
     return;
 
   kdDebug(13000)<<"Slot Activated at pos: "<<symbols->itemIndex(it) <<endl;
-  kv->gotoLineNumber(positions.at(symbols->itemIndex(it)) + 10);
+  kv->gotoLineNumber(it->text(1).toInt(NULL, 10) + 10);
   kv->setFocus();
-  kv->gotoLineNumber(positions.at(symbols->itemIndex(it)));
+  kv->gotoLineNumber(it->text(1).toInt(NULL, 10));
 }
 
 KatePluginSymbolViewer::KatePluginSymbolViewer( QObject* parent, const char* name, const QStringList& )
-    : Kate::Plugin ( (Kate::Application*)parent, name )
+    : Kate::Plugin ( (Kate::Application*)parent, name ),
+    pConfig(new KConfig("katecppsymbolviewerpluginrc"))
 {
+ pConfig->setGroup("global");
 }
 
 KatePluginSymbolViewer::~KatePluginSymbolViewer()
 {
+  pConfig->writeEntry("view_types", m_SymbolView->types_on);
+  pConfig->sync();
+  delete pConfig;
 }
 
 void KatePluginSymbolViewer::addView (Kate::MainWindow *win)
 {
   KatePluginSymbolViewerView *view = new KatePluginSymbolViewerView (win);
+  m_SymbolView = view;
   m_views.append (view);
+  
+  m_SymbolView->types_on = pConfig->readBoolEntry("view_types", true);
 }
 
 void KatePluginSymbolViewer::removeView(Kate::MainWindow *win)
@@ -233,3 +258,54 @@ void KatePluginSymbolViewer::removeView(Kate::MainWindow *win)
       delete view;
     }
 }
+
+Kate::PluginConfigPage* KatePluginSymbolViewer::configPage(
+    uint, QWidget *w, const char* /*name*/)
+{
+  KatePluginSymbolViewerConfigPage* p = new KatePluginSymbolViewerConfigPage(this, w);
+  initConfigPage( p );
+  connect( p, SIGNAL(configPageApplyRequest(KatePluginSymbolViewerConfigPage*)),
+      SLOT(applyConfig(KatePluginSymbolViewerConfigPage *)) );
+  return (Kate::PluginConfigPage*)p;
+}
+
+void KatePluginSymbolViewer::initConfigPage( KatePluginSymbolViewerConfigPage* p )
+{
+  p->viewReturns->setChecked(m_SymbolView->types_on);
+}
+
+void KatePluginSymbolViewer::applyConfig( KatePluginSymbolViewerConfigPage* p )
+{
+  m_SymbolView->types_on = p->viewReturns->isChecked();
+  //kdDebug(13000)<<"KatePluginSymbolViewer: Configuration applied.("<<m_SymbolView->types_on<<")"<<endl;
+  m_SymbolView->slotRefreshSymbol();
+}
+
+// BEGIN KatePluginSymbolViewerConfigPage
+KatePluginSymbolViewerConfigPage::KatePluginSymbolViewerConfigPage(
+    QObject* /*parent*/ /*= 0L*/, QWidget *parentWidget /*= 0L*/)
+  : Kate::PluginConfigPage( parentWidget )
+{
+  QVBoxLayout* top = new QVBoxLayout(this, 0,
+      KDialogBase::spacingHint());
+
+  QGroupBox* gb = new QGroupBox( i18n("Parser Options"),
+      this, "cppsymbolviewer_config_page_layout" );
+  gb->setColumnLayout(1, Qt::Vertical);
+  gb->setInsideSpacing(KDialogBase::spacingHint());
+  viewReturns = new QCheckBox(i18n("Display functions' parameters"), gb);
+
+  top->add(gb);
+  top->addStretch(1);
+//  throw signal changed
+  connect(viewReturns, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
+}
+
+KatePluginSymbolViewerConfigPage::~KatePluginSymbolViewerConfigPage() {}
+
+void KatePluginSymbolViewerConfigPage::apply()
+{
+    emit configPageApplyRequest( this );
+}
+// END KatePluginSymbolViewerConfigPage
+
