@@ -26,7 +26,10 @@
 #include <cassert>
 #include <kdebug.h>
 #include <qstring.h>
-
+#include <ktexteditor/editinterfaceext.h>
+#include <kapplication.h>
+#include <kcompletion.h>
+#include <klineedit.h>
 #define POP_(x) kdDebug(13000) << #x " = " << flush << x << endl
 
 #include <kgenericfactory.h>
@@ -148,7 +151,8 @@ KatePrompt
         (
         const QString & strTitle,
         const QString & strPrompt,
-        QWidget * that
+        QWidget * that,
+	QStringList *completionList
         )
 {
   //  TODO: Make this a "memory edit" field with a combo box
@@ -156,9 +160,15 @@ KatePrompt
 
   KLineEditDlg dlg(strPrompt, QString::null, that);
   dlg.setCaption(strTitle);
-
-  if (dlg.exec())
+  KCompletion *comple=dlg.lineEdit()->completionObject();
+  comple->setItems(*completionList);
+  if (dlg.exec()) {
+    if (!dlg.text().isEmpty())	{
+	comple->addItem(dlg.text());
+	(*completionList)=comple->items();
+    }
     return dlg.text();
+  }
   else
     return "";
 }
@@ -196,10 +206,13 @@ PluginKateTextFilter::slotFilterProcessExited (KProcess * pProcess)
 	assert (pProcess == m_pFilterShellProcess);
 	Kate::View * kv (application()->activeMainWindow()->viewManager()->activeView());
 	if (!kv) return;
+	KTextEditor::EditInterfaceExt *ext=KTextEditor::editInterfaceExt(kv->getDoc());
+	if (ext) ext->editBegin();
 	QString marked = kv->getDoc()->selection ();
 	if (marked.length() > 0)
           kv -> keyDelete ();
 	kv -> insertText (m_strFilterOutput);
+	if (ext) ext->editEnd();
 //	slipInNewText (*kv, "", m_strFilterOutput, "", false);
 	m_strFilterOutput = "";
 
@@ -235,6 +248,10 @@ PluginKateTextFilter::slotFilterCloseStdin (KProcess * pProcess)
                  void
 PluginKateTextFilter::slotEditFilter ()  //  PCP
 {
+  if (!kapp->authorize("shell_access")) {
+      KMessageBox::sorry(0,i18n("You are not allowed to execute arbitrary external applications. If you want to be able to do this, contact your system administrator."),i18n("Access Restrictions"));
+      return;
+  }
   if (!application()->activeMainWindow())
     return;
 
@@ -243,7 +260,8 @@ PluginKateTextFilter::slotEditFilter ()  //  PCP
 
   QString text ( KatePrompt ( i18n("Filter"),
                         i18n("Enter command to pipe selected text through:"),
-                        (QWidget*)  kv
+                        (QWidget*)  kv,
+			&completionList
                         ) );
 
   if ( !text.isEmpty () )
