@@ -51,7 +51,7 @@
 #include <ktempfile.h>
 #include <kate/toolviewmanager.h>
 #include <kgenericfactory.h>
-       
+
 K_EXPORT_COMPONENT_FACTORY( katexmlcheckplugin, KGenericFactory<PluginKateXMLCheck>( "katexmlcheck" ) )
 
 PluginKateXMLCheck::PluginKateXMLCheck( QObject* parent, const char* name, const QStringList& )
@@ -84,7 +84,7 @@ void PluginKateXMLCheck::addView(Kate::MainWindow *win)
 
 	Kate::ToolViewManager *viewmanager = win->toolViewManager();
 	viewmanager->addToolView(KDockWidget::DockBottom, view, SmallIcon("misc"), i18n("XML Checker Output"));
-}   
+}
 
 
 void PluginKateXMLCheck::removeView(Kate::MainWindow *win)
@@ -146,7 +146,7 @@ PluginKateXMLCheckView::PluginKateXMLCheckView(QWidget *parent,Kate::MainWindow
 	connect(m_proc, SIGNAL(receivedStderr(KProcess*,char*,int)),
 		this, SLOT(slotReceivedProcStderr(KProcess*, char*, int)));
 
-}   
+}
 
 
 PluginKateXMLCheckView::~PluginKateXMLCheckView()
@@ -170,7 +170,7 @@ void PluginKateXMLCheckView::slotProcExited(KProcess*)
 	//if( m_dockwidget->isDockBackPossible() ) {
 	//	m_dockwidget->dockBack();
 //	}
-	
+
 	kdDebug() << "slotProcExited()" << endl;
 	//kdDebug() << "output: " << endl << m_proc_stderr << endl << endl;
 	QApplication::restoreOverrideCursor();
@@ -267,7 +267,7 @@ bool PluginKateXMLCheckView::slotValidate()
 	kdDebug() << "slotValidate()" << endl;
 
 	win->toolViewManager()->showToolView (this);
-	
+
 	m_proc->clearArguments();
 	m_proc_stderr = "";
 	m_validating = false;
@@ -283,12 +283,14 @@ bool PluginKateXMLCheckView::slotValidate()
 		return false;
 	}
 	Kate::Document *doc = (Kate::Document*)kv->document();
-	KURL url(doc->url());
-	m_tmp_file = new KTempFile(url.path());
+
+	m_tmp_file = new KTempFile();
 	if( m_tmp_file->status() != 0 ) {
 		kdDebug() << "Error (slotValidate()): could not create '" << m_tmp_file->name() << "': " << m_tmp_file->status() << endl;
 		KMessageBox::error(0, i18n("<b>Error:</b> Could not create "
-			"temporary file in '%1'.").arg(url.directory()));
+			"temporary file '%1'.").arg(m_tmp_file->name()));
+		delete m_tmp_file;
+		m_tmp_file=0L;
 		return false;
 	}
 	QTextStream *s = m_tmp_file->textStream();
@@ -314,7 +316,7 @@ bool PluginKateXMLCheckView::slotValidate()
 		setenv("SGML_CATALOG_FILES", QFile::encodeName( catalogs ).data(), 1);
 	}
 	//kdDebug() << "**catalogs: " << getenv("SGML_CATALOG_FILES") << endl;
-	
+
 	*m_proc << exe << "--catalogs" << "--noout";
 
 	// heuristic: assume that the doctype is in the first 10,000 bytes:
