@@ -342,11 +342,13 @@ void PluginKateXMLTools::getDTD()
 		return;
 	}
 
-	disconnect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)), 0, 0);
+	disconnect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)),
+				this, SLOT(keyEvent(int,int,const QString&)));
 	connect(kv->document(), SIGNAL(charactersInteractivelyInserted(int,int,const QString&)),
 				this, SLOT(keyEvent(int,int,const QString&)));
 
-	disconnect(kv->document(), SIGNAL(backspacePressed()), 0, 0);
+	disconnect(kv->document(), SIGNAL(backspacePressed()),
+				this, SLOT(backspacePressed()));
 	connect(kv->document(), SIGNAL(backspacePressed()),
 				this, SLOT(backspacePressed()));
 
@@ -623,7 +625,7 @@ void PluginKateXMLTools::filterInsertString(KTextEditor::CompletionEntry *ce, QS
 			str = "></" + ce->text + ">";
 		}
 		*text = *text + str;
-		m_correct_pos = - str.length();		// place cursor after tag name (not between the tags!)
+//m_correct_pos = - str.length();		// place cursor after tag name (not between the tags!)
 	}
 }
 
