@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_html.cpp,v 1.5.2.1 2003/07/18 00:59:44 mueller Exp $
+ *  $Id: kfile_html.cpp 345121 2004-09-08 22:27:01Z dfaure $
  */
 
 #include "kfile_html.h"
@@ -38,15 +38,15 @@ KHtmlPlugin::KHtmlPlugin( QObject *parent, const char *name,
     : KFilePlugin( parent, name, args )
 {
     kdDebug(7034) << "html plugin\n";
-    
+
     KFileMimeTypeInfo* info = addMimeTypeInfo("text/html");
 
     KFileMimeTypeInfo::GroupInfo* group;
     KFileMimeTypeInfo::ItemInfo* item;
 
     group = addGroupInfo(info, "General", i18n("General"));
-    addItemInfo(group, "Doctype", i18n("Document type"), QVariant::String);
-    addItemInfo(group, "Javascript", i18n("Javascript"), QVariant::Bool);
+    addItemInfo(group, "Doctype", i18n("Document Type"), QVariant::String);
+    addItemInfo(group, "Javascript", i18n("JavaScript"), QVariant::Bool);
     item = addItemInfo(group, "Title", i18n("Title"), QVariant::String);
     setHint(item, KFileMimeTypeInfo::Name);
 
@@ -57,16 +57,22 @@ KHtmlPlugin::KHtmlPlugin( QObject *parent, const char *name,
 
 bool KHtmlPlugin::readInfo( KFileMetaInfo& info, uint )
 {
+    if ( info.path().isEmpty() ) // remote file
+        return false;
+
     QFile f(info.path());
     if (!f.open(IO_ReadOnly))
         return false;
- 
+
     // we're only interested in the header, so just read until before </head>
     // or until <body> if the author forgot it
-    QByteArray data(f.size()+1);
-    f.readBlock(data.data(), f.size());
-    data[f.size()]='\0';
- 
+    // In this case, it's better to limit the size of the buffer to something
+    // sensible. Think a 0-filled 3GB file with an .html extension.
+    int maxBufSize = QMIN(f.size(), 32768);
+    QByteArray data(maxBufSize + 1);
+    f.readBlock(data.data(), maxBufSize);
+    data[maxBufSize]='\0';
+
     QString s(data.data());
 
     int start=0, last=0;
@@ -118,7 +124,7 @@ bool KHtmlPlugin::readInfo( KFileMetaInfo& info, uint )
 
         appendItem(metatags, name, content.left(50));
     }
-    
+
     // find out if it contains javascript
     exp.setPattern("<script>");
 
