@@ -41,7 +41,7 @@
 
 extern "C"
 {
-	KPanelApplet* init( QWidget *parent, const QString& configFile ) {
+	KDE_EXPORT KPanelApplet* init( QWidget *parent, const QString& configFile ) {
 		KGlobal::locale()->insertCatalogue( "kbinaryclock");
 		return new KBinaryClock( configFile, KPanelApplet::Normal,
 							KPanelApplet::Preferences, parent, "kbinaryclock");
