@@ -35,7 +35,7 @@
 
 extern "C"
 {
-    KPanelApplet* init(QWidget *parent, const QString& configFile)
+    KDE_EXPORT KPanelApplet* init(QWidget *parent, const QString& configFile)
     {
         KGlobal::locale()->insertCatalogue("ktimemon");
         KTimeMon *mon = new KTimeMon(configFile, KPanelApplet::Normal,
