@@ -30,6 +30,7 @@
 #include "xmmsInterface.h"
 #include "jukInterface.h"
 #include "amarokInterface.h"
+#include "kscdInterface.h"
 
 #include "mcslider.h"
 
@@ -55,7 +56,7 @@ const int NO_BUTTONS=4;
 
 extern "C"
 {
-	KPanelApplet *init( QWidget *parent, const QString &configFile)
+	KDE_EXPORT KPanelApplet *init( QWidget *parent, const QString &configFile)
 	{
 		KGlobal::locale()->insertCatalogue("mediacontrol");
 		return new MediaControl(configFile, KPanelApplet::Normal,
@@ -372,6 +373,12 @@ void MediaControl::reparseConfig()
 		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
 			(_configFrontend->mouseWheelSpeed()));
 	}
+	else if (playerString == "KsCD")
+	{
+		_player = new KsCDInterface();
+		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
+			(_configFrontend->mouseWheelSpeed()));
+	}
 	else // Fallback is Noatun
 	{
 		_player = new NoatunInterface();
@@ -592,6 +599,7 @@ void TrayButton::drawButton(QPainter *p)
 	else
 		pbg.fillRect(rect(), colorGroup().brush(QColorGroup::Background));
 
+
 	if (isDown() || isOn())
 	{
 		// Draw shapes to indicate the down state.
