@@ -70,20 +70,32 @@ void CrashesPlugin::slotAboutToShow()
   int count = m_pCrashesMenu->popupMenu()->count();
 
   m_crashesList.clear();
+  m_crashRangesList.clear();
   importer.parseCrashBookmarks( false );
 
   bool gotSep = true; // don't start with a sep
   bool enable = true;
+  int firstItem = count; // item ids grow up from count
+  int crashGroup = INT_MAX; // group ids grow down from INT_MAX
   if (m_crashesList.count() > 0) {
      CrashesList::ConstIterator e = m_crashesList.begin();
      for( ; e != m_crashesList.end(); ++e ) {
         if ( ((*e).first  == "-")
           && ((*e).second == "-")
         ) {
-           if (!gotSep)
+           if (!gotSep) {
+              if (count - firstItem > 1)
+              {
+                 m_crashRangesList.append( CrashRange(firstItem, count) );
+                 m_pCrashesMenu->popupMenu()->insertItem(
+                    i18n("All Pages of this Crash"), this,
+                    SLOT(slotGroupSelected(int)),
+                    0, crashGroup--);
+              }
               m_pCrashesMenu->popupMenu()->insertSeparator();
+           }
            gotSep = true;
-           count++;
+           firstItem = ++count;
         } else {
            QString str = (*e).first;
            if (str.length() > 48) {
@@ -97,6 +109,13 @@ void CrashesPlugin::slotAboutToShow()
            gotSep = false;
         }
      }
+     if (count - firstItem > 1) {
+        m_crashRangesList.append( CrashRange(firstItem, count) );
+        m_pCrashesMenu->popupMenu()->insertItem(
+           i18n("All Pages of this Crash"), this,
+           SLOT(slotGroupSelected(int)),
+           0, crashGroup--);
+     }
   } else {
      m_pCrashesMenu->popupMenu()->insertItem(
         i18n("No Recovered Crashes"), this,
@@ -143,4 +162,32 @@ void CrashesPlugin::slotItemSelected( int id )
      emit m_part->browserExtension()->openURLRequest( url );
 }
 
+void CrashesPlugin::slotGroupSelected( int range )
+{
+  if (!m_part)
+     return;
+     
+  range = INT_MAX - range;
+
+  if (m_crashesList.count() == 0 || m_crashRangesList.count() == 0)
+     return;
+
+  CrashRange r = m_crashRangesList[range];
+  int from = r.first;
+  int i = from;
+
+  if (m_part) {
+     KParts::URLArgs urlargs;
+     urlargs.setNewTab( true );
+     do {
+       KURL url( m_crashesList[i].second );
+       // Open first one in current tab
+       if (i == from)
+         emit m_part->browserExtension()->openURLRequest( url );
+       else
+         emit m_part->browserExtension()->createNewWindow( url, urlargs );
+     } while (++i < r.second);
+  }
+}
+
 #include "crashesplugin.moc"
