@@ -20,6 +20,13 @@
 #include <sys/types.h>
 
 #include <qtimer.h>
+#include <qapplication.h>
+#include <qlabel.h>
+#include <qpushbutton.h>
+#include <qhbox.h>
+#include <qwhatsthis.h>
+#include <qiconview.h>
+#include <klistview.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -31,6 +38,8 @@
 #include <kiconloader.h>
 
 #include <kdirlister.h>
+#include <klistviewsearchline.h>
+#include <kiconviewsearchline.h>
 #include <konq_dirpart.h>
 #include <konq_propsview.h>
 #include <kstaticdeleter.h>
@@ -45,7 +54,7 @@ static KStaticDeleter<SessionManager> dirfiltersd;
 SessionManager *SessionManager::self ()
 {
   if (!m_self)
-    m_self = dirfiltersd.setObject(new SessionManager);
+    m_self = dirfiltersd.setObject(m_self, new SessionManager);
 
   return m_self;
 }
@@ -126,45 +135,73 @@ void SessionManager::loadSettings()
 
 DirFilterPlugin::DirFilterPlugin (QObject* parent, const char* name,
                                   const QStringList &)
-                :KParts::Plugin (parent, name)
+                :KParts::Plugin (parent, name), m_pFilterMenu(0)
 {
-  m_part = 0L;
+  m_part = ::qt_cast<KonqDirPart*>(parent);
+
+  if ( !m_part || !m_part->scrollWidget() )
+    return;
 
   m_pFilterMenu = new KActionMenu (i18n("View F&ilter"), "filter",
                                    actionCollection(), "filterdir");
   m_pFilterMenu->setDelayed (false);
+  m_pFilterMenu->setWhatsThis(i18n("Allow to filter the currently displayed items by filetype."));
 
   connect (m_pFilterMenu->popupMenu(), SIGNAL (aboutToShow()),
            SLOT (slotShowPopup()));
 
-  if (parent && parent->inherits ("KonqDirPart"))
-  {
-    m_part = static_cast<KonqDirPart*>(parent);
+  connect (m_part, SIGNAL (itemRemoved(const KFileItem*)),
+           SLOT( slotItemRemoved (const KFileItem*)));
+  connect (m_part, SIGNAL (itemsAdded(const KFileItemList&)),
+           SLOT (slotItemsAdded(const KFileItemList&)));
+  connect (m_part, SIGNAL (itemsFilteredByMime(const KFileItemList&)),
+           SLOT (slotItemsAdded(const KFileItemList&)));
+  connect (m_part, SIGNAL(aboutToOpenURL()), SLOT(slotOpenURL()));
 
-    connect (m_part, SIGNAL (itemRemoved(const KFileItem*)),
-             SLOT( slotItemRemoved (const KFileItem*)));
-    connect (m_part, SIGNAL (itemsAdded(const KFileItemList&)),
-             SLOT (slotItemsAdded(const KFileItemList&)));
-    connect (m_part, SIGNAL (itemsFilteredByMime(const KFileItemList&)),
-             SLOT (slotItemsAdded(const KFileItemList&)));
-    connect (m_part, SIGNAL(aboutToOpenURL()), SLOT(slotOpenURL()));
+  // add a searchline filter for konqis icons/list views
+  QHBox *hbox = new QHBox(m_part->widget());
+  hbox->hide();
+
+  KAction *clear = new KAction(i18n("Clear Filter Field"),
+                               QApplication::reverseLayout() ? "clear_left" : "locationbar_erase",
+                               0, 0, 0, actionCollection(), "clear_filter");
+
+  clear->setWhatsThis(i18n("Clear filter field<p>Clears the content of the filter field."));
+
+  QWidget *search = 0;
+  if ( m_part->scrollWidget()->inherits("QIconView") )
+  {
+    search = new KIconViewSearchLine(hbox);
+    static_cast<KIconViewSearchLine*>(search)->setIconView(static_cast<QIconView*>(m_part->scrollWidget()));
   }
+  else if ( m_part->scrollWidget()->inherits("KListView") )
+  {
+    search = new KListViewSearchLine(hbox);
+    static_cast<KListViewSearchLine*>(search)->setListView(static_cast<KListView*>(m_part->scrollWidget()));
+  }
+
+  if ( search )
+  {
+    QWhatsThis::add(search, i18n("Enter here a text which an item in the view must contain anywhere to be shown."));
+    connect(clear, SIGNAL(activated()), search, SLOT(clear()));
+  }
+
+  KWidgetAction *filterAction = new KWidgetAction(hbox, i18n("Filter Field"),
+                                                  0, 0, 0, actionCollection(), "toolbar_filter_field");
+  filterAction->setShortcutConfigurable(false);
 }
 
 DirFilterPlugin::~DirFilterPlugin()
 {
   delete m_pFilterMenu;
-
-  m_part = 0;
-  m_pFilterMenu = 0;
 }
 
 void DirFilterPlugin::slotOpenURL ()
 {
   KURL url = m_part->url();
 
-  //kdDebug() << "DirFilterPlugin: New URL    : " << url.url() << endl;
-  //kdDebug() << "DirFilterPlugin: Current URL: " << m_pURL.url() << endl;
+  //kdDebug(90190) << "DirFilterPlugin: New URL    : " << url.url() << endl;
+  //kdDebug(90190) << "DirFilterPlugin: Current URL: " << m_pURL.url() << endl;
 
   if (m_pURL != url)
   {
