@@ -1,15 +1,17 @@
 #include "plugin_domtreeviewer.h"
+#include "domtreewindow.h"
+#include "domtreeview.h"
 
 #include <kaction.h>
 #include <kinstance.h>
+#include <klibloader.h>
 
+#include <kdebug.h>
 #include <klocale.h>
 #include <kgenericfactory.h>
 
 #include <khtml_part.h>
 
-#include <domtreeview.h>
-
 typedef KGenericFactory<PluginDomtreeviewer> DomtreeviewerFactory;
 K_EXPORT_COMPONENT_FACTORY( libdomtreeviewerplugin, DomtreeviewerFactory( "domtreeviewer" ) )
 
@@ -25,16 +27,30 @@ PluginDomtreeviewer::PluginDomtreeviewer( QObject* parent, const char* name,
 
 PluginDomtreeviewer::~PluginDomtreeviewer()
 {
+  kdDebug(90180) << k_funcinfo << endl;
+  delete m_dialog;
 }
 
 void PluginDomtreeviewer::slotShowDOMTree()
 {
-  if( parent() && parent()->inherits("KHTMLPart"))
-    {
-       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
-      DOMTreeView * dtv = new DOMTreeView(0, part, "DomTreeView", false);
-      dtv->show();
-    }
+  kdDebug(90180) << k_funcinfo << "m_dialog " << (void *)m_dialog << endl;
+  if ( m_dialog )
+  {
+    delete m_dialog;
+    Q_ASSERT((DOMTreeWindow *)m_dialog == (DOMTreeWindow *)0);
+  }
+  if (KHTMLPart *part = ::qt_cast<KHTMLPart *>(parent()))
+  {
+    m_dialog = new DOMTreeWindow(this);
+    m_dialog->view()->setHtmlPart(part);
+    m_dialog->show();
+  }
+}
+
+void PluginDomtreeviewer::slotDestroyed()
+{
+  kdDebug(90180) << k_funcinfo << endl;
+  m_dialog = 0;
 }
 
 #include <plugin_domtreeviewer.moc>
