@@ -57,8 +57,8 @@ FSJob::FSJob(FSView* v)
   : KIO::Job(false)
 {
   _view = v;
-  QObject::connect(v, SIGNAL(progress(int,int,QString)),
-                   this, SLOT(progressSlot(int,int,QString)));
+  QObject::connect(v, SIGNAL(progress(int,int,const QString&)),
+                   this, SLOT(progressSlot(int,int,const QString&)));
 }
 
 void FSJob::kill(bool quietly)
@@ -68,7 +68,7 @@ void FSJob::kill(bool quietly)
   Job::kill(quietly);
 }
 
-void FSJob::progressSlot(int percent, int dirs, QString cDir)
+void FSJob::progressSlot(int percent, int dirs, const QString& cDir)
 {
   if (percent<100) {
     emitPercent(percent, 100);
@@ -86,10 +86,10 @@ void FSJob::progressSlot(int percent, int dirs, QString cDir)
 KAboutData* FSViewPart::createAboutData()
 {
   KAboutData* aboutData;
-  aboutData = new KAboutData("fsview", I18N_NOOP("FSView"), "0.1",
+  aboutData = new KAboutData("fsview", I18N_NOOP("FSView"), "0.1.1",
                              I18N_NOOP("Filesystem Utilization Viewer"),
                              KAboutData::License_GPL,
-                             I18N_NOOP("(c) 2003, Josef Weidendorfer"));
+                             I18N_NOOP("(c) 2003-2005, Josef Weidendorfer"));
   return aboutData;
 }
 
@@ -120,6 +120,8 @@ FSViewPart::FSViewPart(QWidget *parentWidget, const char *widgetName,
 
     _areaMenu = new KActionMenu (i18n("Stop at Area"),
 				 actionCollection(), "treemap_areadir");
+    _depthMenu = new KActionMenu (i18n("Stop at Depth"),
+				 actionCollection(), "treemap_depthdir");
     _visMenu = new KActionMenu (i18n("Visualization"),
 				 actionCollection(), "treemap_visdir");
     _colorMenu = new KActionMenu (i18n("Color Mode"),
@@ -137,6 +139,8 @@ FSViewPart::FSViewPart(QWidget *parentWidget, const char *widgetName,
 		      SLOT (slotShowVisMenu()));
     QObject::connect (_areaMenu->popupMenu(), SIGNAL (aboutToShow()),
 		      SLOT (slotShowAreaMenu()));
+    QObject::connect (_depthMenu->popupMenu(), SIGNAL (aboutToShow()),
+		      SLOT (slotShowDepthMenu()));
     QObject::connect (_colorMenu->popupMenu(), SIGNAL (aboutToShow()),
 		      SLOT (slotShowColorMenu()));
 
@@ -220,7 +224,7 @@ void FSViewPart::completedSlot(int dirs)
     _job = 0;
   }
 
-  KConfigGroup cconfig(KGlobal::config(), QCString("MetricCache"));
+  KConfigGroup cconfig(_view->config(), QCString("MetricCache"));
   _view->saveMetric(&cconfig);
 
   emit completed();
@@ -238,6 +242,12 @@ void FSViewPart::slotShowAreaMenu()
   _view->addAreaStopItems(_areaMenu->popupMenu(), 1001, 0);
 }
 
+void FSViewPart::slotShowDepthMenu()
+{
+  _depthMenu->popupMenu()->clear();
+  _view->addDepthStopItems(_depthMenu->popupMenu(), 1501, 0);
+}
+
 void FSViewPart::slotShowColorMenu()
 {
   _colorMenu->popupMenu()->clear();
