@@ -124,7 +124,7 @@ void StoredDrawParams::ensureField(int f)
 }
 
 
-void StoredDrawParams::setField(int f, QString t, QPixmap pm,
+void StoredDrawParams::setField(int f, const QString& t, QPixmap pm,
                            Position p, int maxLines)
 {
   if (f<0 || f>=MAX_FIELD) return;
@@ -136,7 +136,7 @@ void StoredDrawParams::setField(int f, QString t, QPixmap pm,
   _field[f].maxLines = maxLines;
 }
 
-void StoredDrawParams::setText(int f, QString t)
+void StoredDrawParams::setText(int f, const QString& t)
 {
   if (f<0 || f>=MAX_FIELD) return;
   ensureField(f);
@@ -144,7 +144,7 @@ void StoredDrawParams::setText(int f, QString t)
   _field[f].text = t;
 }
 
-void StoredDrawParams::setPixmap(int f, QPixmap pm)
+void StoredDrawParams::setPixmap(int f, const QPixmap& pm)
 {
   if (f<0 || f>=MAX_FIELD) return;
   ensureField(f);
@@ -3054,6 +3054,9 @@ void TreeMapWidget::depthStopActivated(int id)
   }
   else if (id == _depthStopID+2) setMaxDrawingDepth(maxDrawingDepth()-1);
   else if (id == _depthStopID+3) setMaxDrawingDepth(maxDrawingDepth()+1);
+  else if (id == _depthStopID+4) setMaxDrawingDepth(2);
+  else if (id == _depthStopID+5) setMaxDrawingDepth(4);
+  else if (id == _depthStopID+6) setMaxDrawingDepth(6);
 }
 
 void TreeMapWidget::addDepthStopItems(QPopupMenu* popup,
@@ -3081,6 +3084,17 @@ void TreeMapWidget::addDepthStopItems(QPopupMenu* popup,
     }
   }
 
+  popup->insertSeparator();
+  int depth = 2, count;
+  for (count=0;count<3;count++) {
+    popup->insertItem(i18n("Depth %1").arg(depth), id+4+count);
+    if (depth == maxDrawingDepth()) {
+      popup->setItemChecked(id+4+count, true);
+      foundDepth = true;
+    }
+    depth = (depth==2) ? 4 : 6;
+  }
+
   if (maxDrawingDepth()>1) {
     popup->insertSeparator();
     if (!foundDepth) {
