@@ -117,13 +117,13 @@ public:
   const QFont& font() const;
 
   // attribute setters
-  void setField(int f, QString t, QPixmap pm = QPixmap(),
+  void setField(int f, const QString& t, QPixmap pm = QPixmap(),
                 Position p = Default, int maxLines = 0);
-  void setText(int f, QString);
-  void setPixmap(int f, QPixmap);
+  void setText(int f, const QString&);
+  void setPixmap(int f, const QPixmap&);
   void setPosition(int f, Position);
   void setMaxLines(int f, int);
-  void setBackColor(QColor c) { _backColor = c; }
+  void setBackColor(const QColor& c) { _backColor = c; }
   void setSelected(bool b) { _selected = b; }
   void setCurrent(bool b) { _current = b; }
   void setShaded(bool b) { _shaded = b; }
