@@ -67,11 +67,12 @@ void KImGalleryPlugin::slotExecute()
         KMessageBox::sorry(m_part->widget(), i18n("Creating an image gallery works only on local folders."));
         return;
     }
-    kdDebug() << "dialog is ok" << endl;
+    kdDebug(90170) << "dialog is ok" << endl;
     m_configDlg = new KIGPDialog(m_part->widget(), m_part->url().path(+1));
 
     if ( m_configDlg->exec() == QDialog::Accepted ) {
-        kdDebug() << "dialog is ok" << endl;
+        kdDebug(90170) << "dialog is ok" << endl;
+        m_configDlg->writeConfig();
         m_copyFiles = m_configDlg->copyOriginalFiles();
         m_recurseSubDirectories = m_configDlg->recurseSubDirectories();
         m_useCommentFile = m_configDlg->useCommentFile();
@@ -93,7 +94,7 @@ void KImGalleryPlugin::slotExecute()
             }
         }
     } else {
-        kdDebug() << "dialog is not ok" << endl;
+        kdDebug(90170) << "dialog is not ok" << endl;
     }
     delete m_progressDlg;
 }
@@ -124,7 +125,7 @@ void KImGalleryPlugin::createHead(QTextStream& stream)
     stream << "<head>" << endl;
     stream << "<title>" << m_configDlg->getTitle() << "</title>" << endl;
     stream << "<meta http-equiv=\"content-type\" content=\"text/html; charset=" << chsetName << "\"/>" << endl;
-    this->createCSSSection(stream);
+    createCSSSection(stream);
     stream << "</head>" << endl;
 }
 
@@ -205,7 +206,7 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
                 stream << "height=\"" << m_imgHeight << "\" alt=\"" << imgPath << "\"/>";
                 m_progressDlg->setLabelText( i18n("Created thumbnail for: \n%1").arg(imgName) );
             } else {
-                kdDebug() << "Creating thumbnail for " << imgName << " failed" << endl;
+                kdDebug(90170) << "Creating thumbnail for " << imgName << " failed" << endl;
                 m_progressDlg->setLabelText( i18n("Creating thumbnail for: \n%1\n failed").arg(imgName) );
             }
             stream << "</a>" << endl;
@@ -279,7 +280,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
         loadCommentFile();
     }
 
-    kdDebug() << "sourceDirName: " << sourceDirName << endl;
+    kdDebug(90170) << "sourceDirName: " << sourceDirName << endl;
     //We're interested in only the patterns, so look for the first |
     //#### perhaps an accessor should be added to KImageIO instead?
     QString filter = KImageIO::pattern(KImageIO::Reading).section('|', 0, 0);
@@ -288,7 +289,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
                    QDir::Name|QDir::IgnoreCase, QDir::Files|QDir::Readable);
 
     const QString imgGalleryDir = url.directory();
-    kdDebug() << "imgGalleryDir: " << imgGalleryDir << endl;
+    kdDebug(90170) << "imgGalleryDir: " << imgGalleryDir << endl;
 
     // Create the "thumbs" subdirectory if necessary
     QDir thumb_dir( imgGalleryDir + QString::fromLatin1("/thumbs/"));
@@ -303,7 +304,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
     }
 
     QFile file( url.path() );
-    kdDebug() << "url.path(): " << url.path() << ", thumb_dir: "<< thumb_dir.path()
+    kdDebug(90170) << "url.path(): " << url.path() << ", thumb_dir: "<< thumb_dir.path()
               << ", imageDir: "<< imageDir.path() << endl;
 
     if ( imageDir.exists() && file.open(IO_WriteOnly) ) {
@@ -355,7 +356,7 @@ void KImGalleryPlugin::deleteCancelledGallery(const KURL& url, const QString& so
         const QString imgName = imageDir[i];
         const QString imgNameFormat = imgName.left(imgName.findRev('.',-1)) + extension(imageFormat);
         bool isRemoved = thumb_dir.remove(imgNameFormat);
-        kdDebug() << "removing: " << thumb_dir.path() << "/" << imgNameFormat << "; "<< isRemoved << endl;
+        kdDebug(90170) << "removing: " << thumb_dir.path() << "/" << imgNameFormat << "; "<< isRemoved << endl;
     }
     // ..and the thumb directory
     thumb_dir.rmdir(thumb_dir.path());
@@ -365,7 +366,7 @@ void KImGalleryPlugin::deleteCancelledGallery(const KURL& url, const QString& so
         for (uint i=0; i < imageDir.count(); i++) {
             const QString imgName = imageDir[i];
             bool isRemoved = images_dir.remove(imgName);
-            kdDebug() << "removing: " << images_dir.path() << "/" << imgName << "; "<< isRemoved << endl;
+            kdDebug(90170) << "removing: " << images_dir.path() << "/" << imgName << "; "<< isRemoved << endl;
         }
         images_dir.rmdir(images_dir.path());
     }
@@ -375,7 +376,7 @@ void KImGalleryPlugin::loadCommentFile()
 {
     QFile file(m_configDlg->getCommentFile());
     if (file.open(IO_ReadOnly)) {
-        kdDebug() << "File opened."<< endl;
+        kdDebug(90170) << "File opened."<< endl;
 
         QTextStream* m_textStream = new QTextStream(&file);
         m_textStream->setEncoding(QTextStream::Locale);
@@ -392,25 +393,25 @@ void KImGalleryPlugin::loadCommentFile()
                 if (curLineStripped.right(1)==":") {
                     picComment = "";
                     picName = curLineStripped.left(curLineStripped.length()-1);
-                    kdDebug() << "picName: " << picName << endl;
+                    kdDebug(90170) << "picName: " << picName << endl;
                 } else {
                     do {
-                        //kdDebug() << "picComment" << endl;
+                        //kdDebug(90170) << "picComment" << endl;
                         picComment += curLine + "\n";
                         curLine = m_textStream->readLine();
                     } while (!m_textStream->eof() && !(curLine.stripWhiteSpace().isEmpty()) &&
                              !(curLine.stripWhiteSpace().left(1)=="#"));
-                    //kdDebug() << "Pic comment: " << picComment << endl;
+                    //kdDebug(90170) << "Pic comment: " << picComment << endl;
                     m_commentMap->insert(picName, picComment);
                 }
             }
         }
         CommentMap::Iterator it;
         for( it = m_commentMap->begin(); it != m_commentMap->end(); ++it ) {
-            kdDebug() << "picName: " << it.key().local8Bit() << ", picComment: " << it.data().local8Bit() << endl;
+            kdDebug(90170) << "picName: " << it.key().local8Bit() << ", picComment: " << it.data().local8Bit() << endl;
         }
         file.close();
-        kdDebug() << "File closed." << endl;
+        kdDebug(90170) << "File closed." << endl;
         delete m_textStream;
     } else {
         KMessageBox::sorry(m_part->widget(), i18n("Couldn't open file: %1").arg(m_configDlg->getCommentFile()));
@@ -426,9 +427,9 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
 
     if (m_copyFiles) {
         KURL srcURL = KURL::fromPathOrURL(pixPath);
-        //kdDebug() << "srcURL: " << srcURL << endl;
+        //kdDebug(90170) << "srcURL: " << srcURL << endl;
         KURL destURL = KURL::fromPathOrURL(imgGalleryDir + QString::fromLatin1("/images/") + imgName);
-        //kdDebug() << "destURL: " << destURL << endl;
+        //kdDebug(90170) << "destURL: " << destURL << endl;
         KIO::NetAccess::copy(srcURL, destURL, static_cast<KParts::Part *>(parent())->widget());
     }
 
@@ -445,7 +446,7 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
     {
         int w = img.width(), h = img.height();
         // scale to pixie size
-        // kdDebug() << "w: " << w << " h: " << h << endl;
+        // kdDebug(90170) << "w: " << w << " h: " << h << endl;
         // Resizing if to big
         if(w > extent || h > extent)
         {
@@ -466,7 +467,7 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
             const QImage scaleImg(img.smoothScale( w, h ));
             if ( scaleImg.width() != w || scaleImg.height() != h )
             {
-                kdDebug() << "Resizing failed. Aborting." << endl;
+                kdDebug(90170) << "Resizing failed. Aborting." << endl;
                 return false;
             }
             img = scaleImg;
@@ -476,10 +477,10 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
                 img = depthImg;
             }
         }
-        kdDebug() << "Saving thumbnail to: " << thumbDir + imgNameFormat  << endl;
+        kdDebug(90170) << "Saving thumbnail to: " << thumbDir + imgNameFormat  << endl;
         if (!img.save(thumbDir + imgNameFormat, imageFormat.latin1()))
         {
-            kdDebug() << "Saving failed. Aborting." << endl;
+            kdDebug(90170) << "Saving failed. Aborting." << endl;
             return false;
         }
         m_imgWidth = w;
