@@ -22,6 +22,7 @@
 #include <qfileinfo.h>
 
 #include <kaction.h>
+#include <kapplication.h>
 #include <kiconloader.h>
 #include <kio/global.h>
 #include <klocale.h>
@@ -69,7 +70,7 @@ void KDirMenu::slotAboutToShow( ) {
 
     // ok, prepare the dir: list all dirs and insert the new menus
     if (count() >= 1) return;
-    
+
     //Precaution: if not a directory, exit, in case some path in KMetaMenu
     //isn't checked right
     if ( !QFileInfo(path).isDir() )
@@ -106,8 +107,14 @@ void KDirMenu::slotAboutToShow( ) {
         QString fileName = (*it)->fileName();
         if ( fileName == dot || fileName == dotdot )
             continue;
-        insert(new KDirMenu(this, src, (*it)->absFilePath(), name),
+            
+        KURL u;
+        u.setPath((*it)->absFilePath());
+        if (kapp->authorizeURLAction("list", u, u))
+        {
+           insert(new KDirMenu(this, src, (*it)->absFilePath(), name),
 			KIO::decodeFileName( fileName ));
+	}
     }
 }
 void KDirMenu::slotAboutToHide( ) {
