@@ -25,17 +25,20 @@
 
 #include <kaction.h>
 
-class KConfig;
 class QIconSet;
-class KDirMenu;
 class QStringList;
+class KConfig;
+class KDirMenu;
+class KIMContactMenu;
+class KIMProxy;
 class KURL;
+
 class KMetaMenu : public QPopupMenu {
     Q_OBJECT
 public:
 
      KMetaMenu( QWidget *parent, const KURL &url, const QString &text, 
-             const QString &key );
+             const QString &key, KIMProxy * imProxy = 0L );
      KMetaMenu();
      ~KMetaMenu();
      void writeConfig( const QString &path );
@@ -45,11 +48,14 @@ public slots:
      void slotBrowse( );
 signals:
      void fileChosen( const QString &path );
+	 void contactChosen( const QString &uid );
 private:
      KDirMenu *m_root;
      KDirMenu *m_home;
      KDirMenu *m_etc;
      KDirMenu *m_current;
+	 KIMContactMenu *m_contacts;
+	 KIMProxy *m_proxy;
      KAction *m_browse;
      QStringList list;
      KConfig *conf;
