@@ -1,8 +1,9 @@
 // -*- Mode: C++; c-basic-offset: 2; indent-tabs-mode: nil; tab-width: 8; -*-
 
 /***************************************************************************
-    nspanel.h
-    Marcus Camen  <mcamen@mcamen.de>
+    configfeeds.h
+    Copyright: Marcus Camen  <mcamen@mcamen.de>
+    Copyright: Nathan Toone  <nathan@toonetown.com>
 ***************************************************************************/
 
 /*
@@ -27,9 +28,13 @@
 
 #include "configfeedsbase.h"
 
-class QStringList;
-class QListBoxItem;
-class QString;
+
+//
+//
+// ATM this is just a noop wrapper
+//
+//
+
 
 namespace KSB_News {
 
@@ -38,18 +43,7 @@ namespace KSB_News {
     Q_OBJECT
 
   public:
-    ConfigFeeds( QWidget* parent,  const char* name = 0 );
-    QStringList getFeedlist();
-
-  private slots:
-    void slotAdd();
-    void slotEdit();
-    void slotRemove();
-    void slotCurrentChanged(QListBoxItem *item);
-    void slotUrlChanged( const QString & text );
-
-  private:
-    QStringList m_feedlist;
+    ConfigFeeds(QWidget* parent,  const char* name = 0);
 
   };
 
