@@ -1,7 +1,7 @@
 // -*- Mode: C++; c-basic-offset: 2; indent-tabs-mode: nil; tab-width: 8; -*-
 
 /***************************************************************************
-    norsswidget.h
+    Copyright: norsswidget.h
     Marcus Camen  <mcamen@mcamen.de>
 ***************************************************************************/
 
@@ -26,7 +26,7 @@
 #define _NORSSWIDGET_H_
 
 
-class KDialogBase;
+class KConfigDialog;
 
 
 namespace KSB_News {
@@ -42,7 +42,7 @@ namespace KSB_News {
     void slotConfigure_okClicked();
 
   private:
-    KDialogBase *m_confdlg;
+    KConfigDialog *m_confdlg;
   };
 
 
