@@ -30,7 +30,7 @@
 #include "validatorsdialog.moc"
 
 ValidatorsDialog::ValidatorsDialog(QWidget *parent,  const char *name )
-  : KDialogBase( parent, name, true, i18n("Configure"), Ok|Cancel, Ok, true )
+  : KDialogBase( parent, name, false, i18n("Configure"), Ok|Cancel, Ok, true )
 {
   setCaption(i18n("Configure Validating Servers"));
   setMinimumWidth(300);
@@ -83,7 +83,7 @@ ValidatorsDialog::ValidatorsDialog(QWidget *parent,  const char *name )
   m_linkValidatorCB->setDuplicatesEnabled(false);
   vlay3->addWidget( m_linkValidatorCB );
 
-  this->load();
+  load();
 }
 
 ValidatorsDialog::~ValidatorsDialog()
@@ -165,12 +165,12 @@ void ValidatorsDialog::save()
 
 void ValidatorsDialog::slotOk()
 {
-   this->save();
-   this->hide();
+   save();
+   hide();
 }
 
 void ValidatorsDialog::slotCancel()
 {
-   this->load();
-   this->hide();
+   load();
+   hide();
 }
