@@ -17,7 +17,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_webarchiver.cpp 290283 2004-02-22 17:57:53Z dnaber $ */
+/* $Id: plugin_webarchiver.cpp 424045 2005-06-10 15:31:07Z pletourn $ */
 
 /*
  * There are two recursions within this code:
@@ -86,7 +86,7 @@ void PluginWebArchiver::slotSaveToArchive()
 
   archiveName = QDir::homeDirPath() + "/" + archiveName + ".war"; //Thanks ade
 
-  KURL url = KFileDialog::getSaveFileName(archiveName, i18n("*.war *.tgz|Web Archives"), part->widget(),
+  KURL url = KFileDialog::getSaveURL(archiveName, i18n("*.war *.tgz|Web Archives"), part->widget(),
 					  i18n("Save Page as Web-Archive") );
 
   if (url.isEmpty()) { return; }
