@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: webarchivecreator.cpp 304977 2004-04-19 19:02:10Z mueller $
+// $Id: webarchivecreator.cpp 424101 2005-06-10 19:53:13Z pletourn $
 
 #include <time.h>
 
@@ -58,7 +58,11 @@ bool WebArchiveCreator::create(const QString &path, int width, int height, QImag
 		m_html->setJavaEnabled(false);
 		m_html->setPluginsEnabled(false);
 	}
-	m_html->openURL(KURL( "tar:" + path + "/index.html" ));
+	KURL url;
+	url.setProtocol( "tar" );
+	url.setPath( path );
+	url.addPath( "index.html" );
+	m_html->openURL( url );
 	m_completed = false;
 	startTimer(5000);
 	while (!m_completed)
