@@ -1,4 +1,4 @@
-// Copyright (c) 2003 Charles Samuels <charles@kde.org>
+// Copyright (c) 2003,2004 Charles Samuels <charles@kde.org>
 // See the file COPYING for redistribution terms.
 
 #ifndef VIEW_H
@@ -10,18 +10,31 @@
 
 #include "tree.h"
 
+class SchemaListAction;
+class TabWidget;
+
 class View : public KMainWindow
 {
 Q_OBJECT
+	Oblique *mOblique;
 	Tree *mTree;
+	QValueList<Tree*> mTrees;
+	TabWidget *mTabs;
+	KAction *mRemoveTabAction;
+	SchemaListAction *mSchemaListAction;
 
 public:
-	View(Oblique *oblique, Query *query);
+	View(Oblique *oblique);
+	~View();
 
 	Tree *tree() { return mTree; }
 
+	Oblique *oblique() { return mOblique; }
+
 public slots:
 	void addFiles();
+	void addTab();
+	void removeTab();
 
 signals:
 	void listHidden();
@@ -31,6 +44,9 @@ private slots:
 	void configureToolBars();
 	void newToolBarConfig();
 	void jumpTextChanged(const QString &text);
+	void use(Slice*);
+	void currentTabChanged(QWidget *);
+	void setSchema(const QString &file);
 
 protected:
 	virtual void showEvent(QShowEvent *) { emit listShown(); }
