@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
-  675 Mass Ave, Cambridge, MA 02139, USA.
+  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifndef SYNA_H
@@ -60,6 +60,9 @@ typedef unsigned short sampleType;
 #endif
 #ifdef HAVE_ENDIAN_H
 #include <endian.h>
+#elif defined(_BIG_ENDIAN) 
+#define BIG_ENDIAN 1
+#define BYTE_ORDER BIG_ENDIAN
 #endif
 typedef short sampleType;
 #endif
